# probadg Package


This is a probability package that contains classes to create binomial and Gaussian distributions. It also contains a RandomObject class that simulates all the possible results of a binomial random variable, with their corresponding probabilities.

Furthermore, it contains a function that simulates the Bayes Algorithm. 

## Installation:


To install the package you could just use:

`pip install probadg`

## Tools and Software Used


+ Numpy v.1.19.2
+ Matplotlib v.0.23.2
+ Math
+ Pandas v.1.1.3

## License

This software is licensed under the [MIT](https://opensource.org/licenses/MIT) license. The license can be found in the `license.txt` file. 

## Acknoledgements

This package was done under the guidance of [Udacity](udacity.com) Data Science Nano Degree. 

Also, I would like to thank the free online education platforms [Coursera](https://www.coursera.org) and [Edx](https://www.edx.org), which helped me to get started in this path.  

